@@ -20,7 +20,7 @@ test_that(
     # testing all details
     set.seed(123)
     expect_snapshot(select(df1, -expression))
-    expect_snapshot(df1$expression[[1]])
+    expect_snapshot(as.character(df1$expression[[1]]))
 
     # `{statsExpressions}` output
     set.seed(123)
@@ -38,7 +38,7 @@ test_that(
     # testing all details
     set.seed(123)
     expect_snapshot(select(df2, -expression))
-    expect_snapshot(df2$expression[[1]])
+    expect_snapshot(as.character(df2$expression[[1]]))
   }
 )
 
@@ -64,7 +64,7 @@ test_that(
 
     # testing all details
     set.seed(123)
-    expect_snapshot(df1$expression[[1]])
+    expect_snapshot(as.character(df1$expression[[1]]))
 
     # `{statsExpressions}` output
     set.seed(123)
@@ -81,7 +81,7 @@ test_that(
 
     # testing all details
     set.seed(123)
-    expect_snapshot(df2$expression[[1]])
+    expect_snapshot(as.character(df2$expression[[1]]))
   }
 )
 
@@ -141,6 +141,6 @@ test_that(
         paired = TRUE
       )
 
-    expect_equal(expr1, expr2)
+    expect_equal(expr1, expr2, ignore_attr = TRUE)
   }
 )
